@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2006 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2006 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "contentindextest.h"
@@ -60,12 +47,12 @@ void ContentIndexTest::testFromString()
 
 void ContentIndexTest::testContent()
 {
-    Content *c1 = new Content();
+    auto *c1 = new Content();
     QCOMPARE(c1->content(ContentIndex()), c1);
     QCOMPARE(c1->content(ContentIndex(QLatin1String("1"))), (Content *)nullptr);
     QCOMPARE(c1->indexForContent(c1), ContentIndex());
 
-    Content *c11 = new Content();
+    auto *c11 = new Content();
     // this makes c1 multipart/mixed, ie. c11 will be the second child!
     c1->addContent(c11);
     QCOMPARE(c1->content(ContentIndex(QLatin1String("2"))), c11);
@@ -75,10 +62,10 @@ void ContentIndexTest::testContent()
     QCOMPARE(c1->indexForContent(c11), ContentIndex(QLatin1String("2")));
     QCOMPARE(c1->indexForContent(c1->contents().first()), ContentIndex(QLatin1String("1")));
 
-    Content *c12 = new Content();
+    auto *c12 = new Content();
     c1->addContent(c12);
     // c12 becomes multipart/mixed, ie. c12 will be the second child!
-    Content *c121 = new Content();
+    auto *c121 = new Content();
     c12->addContent(c121);
     QCOMPARE(c1->content(ContentIndex(QLatin1String("3"))), c12);
     QCOMPARE(c1->content(ContentIndex(QLatin1String("3.2"))), c121);
