@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef UTIL_TEST_H
-#define UTIL_TEST_H
+#pragma once
 
 #include <QObject>
 
@@ -28,5 +27,4 @@ private Q_SLOTS:
     void testLFCRLF_performance();
 };
 
-#endif
 
