@@ -2,23 +2,10 @@
     kmime_dateformatter.h
 
     KMime, the KDE Internet mail/usenet news message library.
-    Copyright (c) 2001 the KMime authors.
+    SPDX-FileCopyrightText: 2001 the KMime authors.
     See file AUTHORS for details
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 /**
   @file
@@ -44,13 +31,13 @@
   ASCII string of the form "Sun Mar 31 02:08:35 2002".
 */
 
-#ifndef __KMIME_DATEFORMATTER_H__
-#define __KMIME_DATEFORMATTER_H__
+#pragma once
 
 #include <time.h>
 #include <QDateTime>
 #include <QString>
 #include "kmime_export.h"
+#include <memory>
 
 namespace KMime
 {
@@ -193,10 +180,9 @@ public:
 private:
     //@cond PRIVATE
     Q_DISABLE_COPY(DateFormatter)
-    DateFormatterPrivate *const d;
+    std::unique_ptr<DateFormatterPrivate> const d;
     //@endcond
 };
 
 } // namespace KMime
 
-#endif /* __KMIME_DATEFORMATTER_H__ */
