@@ -2,39 +2,23 @@
     kmime_header_parsing.h
 
     KMime, the KDE Internet mail/usenet news message library.
-    Copyright (c) 2001-2002 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2001-2002 Marc Mutz <mutz@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef __KMIME_HEADER_PARSING_H__
-#define __KMIME_HEADER_PARSING_H__
+#pragma once
 
 #include "kmime_export.h"
 #include "kmime_types.h"
 
 #include <QString>
 #include <QPair>
-#include <QVector>
-#include <QFlags>
 
 #include <QDateTime>
 
 template <typename K, typename V> class QMap;
-class QStringList;
+#include <QStringList>
 
 namespace KMime
 {
@@ -47,16 +31,6 @@ class Base;
 namespace Types
 {
 
-// for when we can't make up our mind what to use...
-// FIXME: Remove this thing, we should _always_ know whether we are handling a
-// byte array or a string.
-// In most places where this is used, it should simply be replaced by QByteArray
-struct KMIME_EXPORT QStringOrQPair {
-    QStringOrQPair() : qstring(), qpair(nullptr, 0) {}
-    QString qstring;
-    QPair<const char *, int> qpair;
-};
-
 } // namespace KMime::Types
 
 namespace HeaderParsing
@@ -88,16 +62,18 @@ Q_REQUIRED_RESULT KMIME_EXPORT bool parseEncodedWord(const char *&scursor,
 //
 
 /** You may or may not have already started parsing into the
-    atom. This function will go on where you left off. */
+    atom. This function will go on where you left off.
+ */
 Q_REQUIRED_RESULT KMIME_EXPORT bool parseAtom(const char *&scursor, const char *const send,
-                            QString &result, bool allow8Bit = false);
+                            QByteArray &result, bool allow8Bit = false);
 
+/**
+ * More efficient overload, to avoid a copy of the substring
+ */
 Q_REQUIRED_RESULT KMIME_EXPORT bool parseAtom(const char *&scursor, const char *const send,
                             QPair<const char *, int> &result,
                             bool allow8Bit = false);
 
-/** You may or may not have already started parsing into the
-    token. This function will go on where you left off. */
 enum ParseTokenFlag {
     ParseTokenNoFlag = 0,
     ParseTokenAllow8Bit = 1,
@@ -105,8 +81,10 @@ enum ParseTokenFlag {
 };
 Q_DECLARE_FLAGS(ParseTokenFlags, ParseTokenFlag)
 
+/** You may or may not have already started parsing into the
+    token. This function will go on where you left off. */
 Q_REQUIRED_RESULT KMIME_EXPORT bool parseToken(const char *&scursor, const char *const send,
-                             QString &result, ParseTokenFlags flags = ParseTokenNoFlag);
+                             QByteArray &result, ParseTokenFlags flags = ParseTokenNoFlag);
 
 Q_REQUIRED_RESULT KMIME_EXPORT bool parseToken(const char *&scursor, const char *const send,
                              QPair<const char *, int> &result,
@@ -155,7 +133,7 @@ Q_REQUIRED_RESULT KMIME_EXPORT bool parsePhrase(const char *&scursor, const char
   @return true if the input phrase was successfully parsed; false otherwise.
 */
 Q_REQUIRED_RESULT KMIME_EXPORT bool parseDotAtom(const char *&scursor, const char *const send,
-                               QString &result, bool isCRLF = false);
+                               QByteArray &result, bool isCRLF = false);
 
 /**
   Eats comment-folding-white-space, skips whitespace, folding and comments
@@ -163,7 +141,7 @@ Q_REQUIRED_RESULT KMIME_EXPORT bool parseDotAtom(const char *&scursor, const cha
   calling this function, you should check whether @p scursor == @p send
   (end of header reached).
 
-  If a comment with unbalanced parantheses is encountered, @p scursor
+  If a comment with unbalanced parentheses is encountered, @p scursor
   is being positioned on the opening '(' of the outmost comment.
 
   @param scursor pointer to the first character beyond the initial '=' of
@@ -203,7 +181,7 @@ Q_REQUIRED_RESULT KMIME_EXPORT bool parseAngleAddr(const char *&scursor, const c
   @param result the parsing result
   @param isCRLF true if input string is terminated with a CRLF.
 */
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseMailbox(const char *&scursor, const char *const send,
+KMIME_EXPORT bool parseMailbox(const char *&scursor, const char *const send,
                                Types::Mailbox &result, bool isCRLF = false);
 
 Q_REQUIRED_RESULT KMIME_EXPORT bool parseGroup(const char *&scursor, const char *const send,
@@ -217,20 +195,11 @@ Q_REQUIRED_RESULT KMIME_EXPORT bool parseAddressList(const char *&scursor,
                                    Types::AddressList &result,
                                    bool isCRLF = false);
 
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseParameter(const char *&scursor, const char *const send,
-                                 QPair<QString, Types::QStringOrQPair> &result,
-                                 bool isCRLF = false);
-
 Q_REQUIRED_RESULT KMIME_EXPORT bool parseParameterList(const char *&scursor,
                                      const char *const send,
                                      QMap<QString, QString> &result,
                                      bool isCRLF = false);
 
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseRawParameterList(const char *&scursor,
-                                        const char *const send,
-                                        QMap<QString, Types::QStringOrQPair> &result,
-                                        bool isCRLF = false);
-
 /**
  * Extract the charset embedded in the parameter list if there is one.
  *
@@ -285,5 +254,4 @@ KMIME_EXPORT void extractHeaderAndBody(const QByteArray &content,
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KMime::HeaderParsing::ParseTokenFlags)
 
-#endif // __KMIME_HEADER_PARSING_H__
 
