@@ -2,24 +2,11 @@
     kmime_headers.h
 
     KMime, the KDE Internet mail/usenet news message library.
-    Copyright (c) 2001-2002 the KMime authors.
+    SPDX-FileCopyrightText: 2001-2002 the KMime authors.
     See file AUTHORS for details
-    Copyright (c) 2006 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2006 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 /**
   @file
@@ -37,8 +24,7 @@
   Volker Krause \<vkrause@kde.org\>
 */
 
-#ifndef __KMIME_HEADERS_H__
-#define __KMIME_HEADERS_H__
+#pragma once
 
 #include "kmime_export.h"
 #include "kmime_header_parsing.h"
@@ -46,7 +32,6 @@
 #include <QString>
 #include <QStringList>
 #include <QDateTime>
-#include <QMap>
 #include <QVector>
 #include <QByteArray>
 #include <QMetaType>
@@ -95,7 +80,7 @@ enum contentDisposition {
 #define kmime_mk_trivial_ctor( subclass )                               \
     public:                                                               \
     subclass();                           \
-    ~subclass();
+    ~subclass() override;
 
 #define kmime_mk_dptr_ctor( subclass ) \
     protected: \
@@ -245,7 +230,7 @@ class KMIME_EXPORT Unstructured : public Base
     //@endcond
 public:
     Unstructured();
-    ~Unstructured();
+    ~Unstructured() override;
 
     using Base::from7BitString;
     void from7BitString(const QByteArray &s) override;
@@ -298,7 +283,7 @@ class KMIME_EXPORT Structured : public Base
 {
 public:
     Structured();
-    ~Structured();
+    ~Structured() override;
 
     void from7BitString(const char *s, size_t len) override;
     void from7BitString(const QByteArray &s) override;
@@ -334,7 +319,7 @@ class KMIME_EXPORT Address : public Structured
 {
 public:
     Address();
-    ~Address();
+    ~Address() override;
 protected:
     //@cond PRIVATE
     kmime_mk_dptr_ctor(Address)
@@ -935,7 +920,7 @@ class KMIME_EXPORT MessageID : public Generics::SingleIdent
     //@endcond
 public:
     /**
-      Generate a message identifer.
+      Generate a message identifier.
       @param fqdn A fully qualified domain name.
     */
     void generate(const QByteArray &fqdn);
@@ -1062,7 +1047,7 @@ public:
     bool isImage() const;
 
     /**
-      Returns true if the associated MIME entity is a mulitpart container.
+      Returns true if the associated MIME entity is a multipart container.
     */
     bool isMultipart() const;
 
@@ -1083,12 +1068,12 @@ public:
     void setCharset(const QByteArray &s);
 
     /**
-      Returns the boundary (for mulitpart containers).
+      Returns the boundary (for multipart containers).
     */
     QByteArray boundary() const;
 
     /**
-      Sets the mulitpart container boundary.
+      Sets the multipart container boundary.
     */
     void setBoundary(const QByteArray &s);
 
@@ -1211,7 +1196,7 @@ class KMIME_EXPORT Generic : public Generics::Unstructured
 public:
     Generic();
     Generic(const char *t, int len = -1);
-    ~Generic();
+    ~Generic() override;
 
     void clear() override;
 
@@ -1461,4 +1446,3 @@ Q_DECLARE_METATYPE(KMime::Headers::To*)
 Q_DECLARE_METATYPE(KMime::Headers::Cc*)
 Q_DECLARE_METATYPE(KMime::Headers::Bcc*)
 
-#endif // __KMIME_HEADERS_H__
